/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "MPL"); you may not use this file
 * except in compliance with the MPL. You may obtain a copy of
 * the MPL at http://www.mozilla.org/MPL/
 *
 * Software distributed under the MPL is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the MPL for the specific language governing
 * rights and limitations under the MPL.
 *
 * The Original Code is Enigmail.
 *
 * The Initial Developer of the Original Code is Ramalingam Saravanan.
 * Portions created by Ramalingam Saravanan <svn@xmlterm.org> are
 * Copyright (C) 2001 Ramalingam Saravanan. All Rights Reserved.
 *
 * Contributor(s):
 * Patrick Brunschwig <patrick.brunschwig@gmx.net>
 *
 * Alternatively, the contents of this file may be used under the
 * terms of the GNU General Public License (the "GPL"), in which case
 * the provisions of the GPL are applicable instead of
 * those above. If you wish to allow use of your version of this
 * file only under the terms of the GPL and not to allow
 * others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them
 * with the notice and other provisions required by the GPL.
 * If you do not delete the provisions above, a recipient
 * may use your version of this file under either the MPL or the
 * GPL.
 */

// Implementations supplied by this module
const NS_ENIGMAIL_CONTRACTID   = "@mozdev.org/enigmail/enigmail;1";
const NS_ENIGMAIL_CID = 
  Components.ID("{847b3a01-7ab1-11d4-8f02-006c08948af5}");


// interafces used in this file
const nsICategoryManager = Components.interfaces.nsICategoryManager;
const nsISupports        = Components.interfaces.nsISupports;

var gEnigmailSvc = null;

function Enigmail()
{}

Enigmail.prototype.initialized = true;

Enigmail.prototype.QueryInterface =
function (iid) {

  //DEBUG_LOG("Enigmail.QueryInterface:\n");
  if (!iid.equals(Components.interfaces.nsIEnigmail) &&
      !iid.equals(Components.interfaces.nsIObserver) &&
      !iid.equals(Components.interfaces.nsISupports))
  throw Components.results.NS_ERROR_NO_INTERFACE;

  return this;
}

// factory for command line handler service (Enigmail)
function EnigmailFactory ()
{}

EnigmailFactory.prototype.QueryInterface = function (iid) {

    //DEBUG_LOG("EnigmailFactory.QueryInterface:"+iid+"\n");
    if (!iid.equals(Components.interfaces.nsIFactory) &&
        !iid.equals(nsISupports))
    throw Components.results.NS_ERROR_NO_INTERFACE;

    return this;
}
  
EnigmailFactory.prototype.createInstance = function (outer, iid) {
  if (gEnigmailSvc == null) {
    gEnigmailSvc = new Enigmail();
  }
  return gEnigmailSvc;
}


var EnigmailModule = new Object();

EnigmailModule.registerSelf =
function (compMgr, fileSpec, location, type)
{
  dump("Registering Enigmail module.\n");

  compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
  compMgr.registerFactoryLocation(NS_ENIGMAIL_CID,
                                  "Enigmail",
                                  NS_ENIGMAIL_CONTRACTID,
                                  fileSpec,
                                  location,
                                  type);

  dump("Enigmail module registered.\n");
}

EnigmailModule.unregisterSelf =
function(compMgr, fileSpec, location)
{
  compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
  compMgr.unregisterFactoryLocation(NS_ENIGMAIL_CID, fileSpec);

}

EnigmailModule.getClassObject =
function (compMgr, cid, iid) {
  if (cid.equals(NS_ENIGMAIL_CID))
    return new EnigmailFactory();


  if (!iid.equals(Components.interfaces.nsIFactory))
    throw Components.results.NS_ERROR_NOT_IMPLEMENTED;

  throw Components.results.NS_ERROR_NO_INTERFACE;    
}

EnigmailModule.canUnload =
function(compMgr)
{
  return true;
}

// entrypoint
function NSGetModule(compMgr, fileSpec) {
  return EnigmailModule;
}
